@@ -490,33 +490,33 @@ class DataTransformerForm(BaseInlineFormSet):
         super(DataTransformerForm, self).add_fields(form, index)
         dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
                                                              fk_name='parent',
-                                                             extra=1, exclude=['updated_at', 'created_at'], form=DataTransform
+                                                             extra=1, form=DataTransform
                                                              )
-        if form.instance is not None and hasattr(form.instance, 'getChildren'):
+        if form.instance is not None and form.instance._state.adding==False:
             form.nested_data_transformer_form = dataTransformerInlineFormset(
-                initial=form.instance.getChildren(),
+                instance=form.instance,
                 data=form.data if form.is_bound else None,
                 files=form.files if form.is_bound else None
             )
 
 
-        form.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
+            form.nested_constants_form = DataConstantsTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
-        form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
+            form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
-        form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
+            form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
 
     def as_p(self):
         # super(self.__class__,self).as_p()
@@ -546,7 +546,7 @@ class DataTransform(forms.ModelForm):
 
     parent = forms.CharField(required=False,
                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=False,
+    type = forms.CharField(required=True,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
 
